Generate and export highlighted reconstructed linelist

chronofix_linelist(
  samples,
  error_thresholds = c(0.05, 0.5, 0.95),
  format = "xlsx",
  filename = NULL,
  show_p_error = FALSE
)

Arguments

samples

A chronofix_mcmc_samples object as generated by chronofix_mcmc().

error_thresholds

Numeric vector of length 3, giving the posterior probability thresholds to classify a date as a possible error (default 0.05), likely error (default 0.5) and highly likely error (default 0.95).

format

File format for the corrected linelist. Default xlsx.

filename

Output file path. If NULL, defaults to "chronofix_linelist.xlsx".

show_p_error

Logical. If FALSE (default), posterior probability columns are hidden in Excel.

Value

Output line list dataframe with estimated dates in the chosen file format.