Helper function to get status matrix

chronofix_linelist_status_matrix(
  mode_dates_num,
  prob_error,
  error_threshold = 0.5
)

Arguments

mode_dates_num

numeric matrix of estimated dates (calculated as posterior modes) for each individual and event.

prob_error

numeric matrix of the posterior error probabilities for each corresponding date.

error_threshold

numeric cutoff (default 0.5) probabilities greater than or equal to this are classified as "Error".