Summarises posterior samples for each delay distribution described in delay_map, returning the derived mean/CV and the native distribution parameters (shape/scale for Gamma, meanlog/sdlog for Log-Normal), each with posterior mean, posterior median and 95% credible interval.

chronofix_summarise_delays(samples)

Arguments

samples

A chronofix_mcmc_samples object as generated by chronofix_mcmc().

Value

A data frame with one row per delay x parameter (Mean, CV, and the two native distribution parameters (shape/scale for Gamma, meanlog/sdlog for Log-Normal), giving the Posterior_Mean, Posterior_Median and 95% credible interval (Lower_95_CrI, Upper_95_CrI).