chronofix_hyperparameters.RdCreate hyperparameters
chronofix_hyperparameters(
prob_error_shape1 = 1,
prob_error_shape2 = 1,
gamma_shape_prior_shape = 1,
gamma_shape_prior_rate = 1,
gamma_mean_prior_shape = 1,
gamma_mean_prior_scale = 1,
log_normal_meanlog_prior_mean = 0,
log_normal_meanlog_prior_precision = 1,
log_normal_precisionlog_prior_shape = 1,
log_normal_precisionlog_prior_rate = 1
)The first shape parameter of the beta prior distribution for the probability of error
The second shape parameter of the beta prior distribution for the probability of error
The shape parameter of the gamma prior distribution for the shape parameter of a Gamma-distributed delay
The rate parameter of the gamma prior distribution for the shape parameter of a gamma-distributed delay
The shape parameter of the inverse-gamma prior distribution for the mean of a Gamma-distributed delay
The scale parameter of the inverse-gamma prior distribution for the mean of a Gamma-distributed delay
The mean of the normal prior distribution for the mean on the log-scale of a log-normal-distributed delay
The precision of the normal prior distribution for the mean on the log-scale of a log-normal-distributed delay
The shape parameter of the gamma prior distribution for the precision on the log-scale of a log-normal-distributed delay
The rate parameter of the gamma prior distribution for the precision on the log-scale of a log-normal-distributed delay
List of hyperparameters