Create hyperparameters

chronofix_hyperparameters(
  prob_error_shape1 = 1,
  prob_error_shape2 = 1,
  delay_mean_scale = 10,
  delay_cv_scale = 10
)

Arguments

prob_error_shape1

The first shape parameter of the beta prior distribution for the probability of error

prob_error_shape2

The second shape parameter of the beta prior distribution for the probability of error

delay_mean_scale

The scale parameter (mean) of the exponential prior distribution for the means of the delays

delay_cv_scale

The scale parameter (mean) of the exponential prior distribution for the coefficients of variations of the delays

Value

List of hyperparameters