chronofix_hyperparameters.RdCreate hyperparameters
chronofix_hyperparameters(
prob_error_shape1 = 1,
prob_error_shape2 = 1,
delay_mean_scale = 10,
delay_cv_scale = 10
)The first shape parameter of the beta prior distribution for the probability of error
The second shape parameter of the beta prior distribution for the probability of error
The scale parameter (mean) of the exponential prior distribution for the means of the delays
The scale parameter (mean) of the exponential prior distribution for the coefficients of variations of the delays
List of hyperparameters