chronofix_linelist.RdGenerate and export highlighted reconstructed linelist
chronofix_linelist(
samples,
error_thresholds = c(0.05, 0.5, 0.95),
format = "xlsx",
filename = NULL,
show_p_error = FALSE
)A chronofix_mcmc_samples object as generated
by chronofix_mcmc().
Numeric vector of length 3, giving the posterior probability thresholds to classify a date as a possible error (default 0.05), likely error (default 0.5) and highly likely error (default 0.95).
File format for the corrected linelist. Default xlsx.
Output file path. If NULL, defaults to "chronofix_linelist.xlsx".
Logical. If FALSE (default), posterior probability columns are hidden in Excel.
Output line list dataframe with estimated dates in the chosen file format.