Generate and export highlighted reconstructed linelist

chronofix_linelist(
  mcmc_output = NULL,
  observed_data = NULL,
  error_threshold = 0.5,
  format = "xlsx",
  filename = NULL,
  show_p_error = FALSE
)

Arguments

mcmc_output

Samples generated by chronofix_mcmc_run().

observed_data

Original observed data containing the 'id', 'group', and event columns.

error_threshold

Posterior probability threshold to classify a date as an error (default 0.5).

format

File format for the corrected linelist. Default xlsx.

filename

Output file path. If NULL, defaults to "chronofix_linelist.xlsx".

show_p_error

Logical. If FALSE (default), posterior probability columns are hidden in Excel.

Value

Output line list dataframe with estimated dates in the chosen file format.