chronofix_mcmc_initial.RdCreate initial parameter values
chronofix_mcmc_initial(
model,
initial_delay_shape = 1,
initial_delay_mean = 5,
initial_delay_meanlog = 1,
initial_delay_precisionlog = 1,
initial_prob_error = 0.1
)Model
The initial value for the shape parameter of gamma-distributed delays
The initial value for the mean of gamma-distributed delays
The initial value for the mean on the log-scale of log-normal-distributed delays
The initial value for the precision on the log-scale of log-normal-distributed delays
The initial value for the probability of error
Vector of initial parameter values